@@ -29,22 +29,25 @@ test_singularity_installation <- function(detailed = FALSE) {
 
     if (output$status == 1) {
       stop(crayon::red(paste0(
-        "\u274C Singularity (>= 3.0) could not be found. ",
+        "\u274C Singularity (>= 3.0) or Apptainer could not be found. ",
         "Install the latest stable release from: https://github.com/sylabs/singularity/releases."
       )))
     }
 
-    major_version <- as.integer(gsub("^([^.]*)\\..*", "\\1", output$stdout))
-
-    if (major_version < 3) {
-      stop(crayon::red(paste0(
-        "\u274C An older version of Singularity was detected (", output$stdout, "). ",
-        "Install the latest stable release following the installation instructions at https://sylabs.io/docs/."
-      )))
-    }
-
     message(crayon::green(paste0("\u2714 Singularity is installed")))
-    message(crayon::green(paste0("\u2714 Singularity is at correct version (>=3.0): ", gsub("\n", "", output$stdout), " is installed")))
+
+    if (!is_singularity_apptainer()) {
+      major_version <- as.integer(gsub("^([^.]*)\\..*", "\\1", output$stdout))
+
+      if (major_version < 3) {
+        stop(crayon::red(paste0(
+          "\u274C An older version of Singularity was detected (", output$stdout, "). ",
+          "Install the latest stable release following the installation instructions at https://sylabs.io/docs/."
+        )))
+      }
+
+      message(crayon::green(paste0("\u2714 Singularity is at correct version (>=3.0): ", gsub("\n", "", output$stdout), " is installed")))
+    }
 
     output <- processx::run("singularity", c("exec", "docker://alpine:3.7", "echo", "hi"), error_on_status = FALSE, stderr_callback = print_processx, spinner = TRUE, echo = FALSE)
     if (output$status != 0 || output$stdout != "hi\n") {
